# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.artifact_data_presentation import ArtifactDataPresentation

class TestArtifactDataPresentation(unittest.TestCase):
    """ArtifactDataPresentation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ArtifactDataPresentation:
        """Test ArtifactDataPresentation
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ArtifactDataPresentation`
        """
        model = ArtifactDataPresentation()
        if include_optional:
            return ArtifactDataPresentation(
                kind = 'presentation',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
                gamma_generation_id = '',
                pptx_gcs_path = '',
                pptx_export_url = '',
                pptx_signed_url_expires_at = '',
                pdf_gcs_path = '',
                pdf_export_url = '',
                pdf_signed_url_expires_at = '',
                pdf_conversion_started_at = ''
            )
        else:
            return ArtifactDataPresentation(
                kind = 'presentation',
                source_report_artifact_id = '',
                config = keplar_api.models.presentation_config.PresentationConfig(
                    text_amount = 'brief', 
                    image_source = 'aiGenerated', 
                    num_cards = 1.337, 
                    dimensions = 'fluid', 
                    additional_instructions = '', ),
        )
        """

    def testArtifactDataPresentation(self):
        """Test ArtifactDataPresentation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
