# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.repdata_survey_field_details import RepdataSurveyFieldDetails

class TestRepdataSurveyFieldDetails(unittest.TestCase):
    """RepdataSurveyFieldDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepdataSurveyFieldDetails:
        """Test RepdataSurveyFieldDetails
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RepdataSurveyFieldDetails`
        """
        model = RepdataSurveyFieldDetails()
        if include_optional:
            return RepdataSurveyFieldDetails(
                cost = 1.337,
                abandons = 1.337,
                entrants = 1.337,
                inflight = 1.337,
                completes = 1.337,
                final_cost = 1.337,
                accepted_cost = 1.337,
                rejected_cost = 1.337,
                incidence_rate = 1.337,
                final_completes = 1.337,
                accepted_completes = 1.337,
                quality_terminates = 1.337,
                rejected_completes = 1.337,
                defender_terminates = 1.337,
                length_of_interview = 1.337,
                standard_terminates = 1.337,
                overquota_terminates = 1.337,
                accepted_unregistered_cost = 1.337,
                accepted_unregistered_completes = 1.337
            )
        else:
            return RepdataSurveyFieldDetails(
        )
        """

    def testRepdataSurveyFieldDetails(self):
        """Test RepdataSurveyFieldDetails"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
