# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.api_threads_thread_id_project_brief_document_versions_get200_response import ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response

class TestApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(unittest.TestCase):
    """ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response:
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response`
        """
        model = ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response()
        if include_optional:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(
                versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ]
            )
        else:
            return ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(
                versions = [
                    keplar_api.models.brief_document_version.BriefDocumentVersion(
                        doc = keplar_api.models.brief_document.BriefDocument(
                            type = 'doc', 
                            content = [
                                keplar_api.models.content_node.ContentNode()
                                ], ), 
                        version = 1.337, 
                        created_at = '', 
                        updated_at = '', )
                    ],
        )
        """

    def testApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response(self):
        """Test ApiThreadsThreadIdProjectBriefDocumentVersionsGet200Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
