# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.user_admin_level import UserAdminLevel

class TestUserAdminLevel(unittest.TestCase):
    """UserAdminLevel unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testUserAdminLevel(self):
        """Test UserAdminLevel"""
        # inst = UserAdminLevel()

if __name__ == '__main__':
    unittest.main()
