# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.response_call_completed_event import ResponseCallCompletedEvent

class TestResponseCallCompletedEvent(unittest.TestCase):
    """ResponseCallCompletedEvent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseCallCompletedEvent:
        """Test ResponseCallCompletedEvent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseCallCompletedEvent`
        """
        model = ResponseCallCompletedEvent()
        if include_optional:
            return ResponseCallCompletedEvent(
                type = 'CALL_COMPLETED'
            )
        else:
            return ResponseCallCompletedEvent(
                type = 'CALL_COMPLETED',
        )
        """

    def testResponseCallCompletedEvent(self):
        """Test ResponseCallCompletedEvent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
