# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.admin_panel_invite import AdminPanelInvite

class TestAdminPanelInvite(unittest.TestCase):
    """AdminPanelInvite unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AdminPanelInvite:
        """Test AdminPanelInvite
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AdminPanelInvite`
        """
        model = AdminPanelInvite()
        if include_optional:
            return AdminPanelInvite(
                id = '',
                name = '',
                code = '',
                status = 'PREVIEW',
                config = keplar_api.models.invite_config.InviteConfig(),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                    id = '', 
                    name = '', 
                    created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                        id = '', 
                        name = '', 
                        email = '', ), )
            )
        else:
            return AdminPanelInvite(
                id = '',
                name = '',
                code = '',
                status = 'PREVIEW',
                config = keplar_api.models.invite_config.InviteConfig(),
                created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                project = keplar_api.models.admin_panel_invite_project.AdminPanelInvite_project(
                    id = '', 
                    name = '', 
                    created_by = keplar_api.models.admin_panel_invite_project_created_by.AdminPanelInvite_project_createdBy(
                        id = '', 
                        name = '', 
                        email = '', ), ),
        )
        """

    def testAdminPanelInvite(self):
        """Test AdminPanelInvite"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
