# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from keplar_api.models.supported_language import SupportedLanguage
from keplar_api.models.vapi_voice import VapiVoice
from typing import Optional, Set
from typing_extensions import Self

class ProjectConversationConfig(BaseModel):
    """
    ProjectConversationConfig
    """ # noqa: E501
    first_message: StrictStr = Field(alias="firstMessage")
    end_call_message: StrictStr = Field(alias="endCallMessage")
    max_duration_seconds: Union[StrictFloat, StrictInt] = Field(alias="maxDurationSeconds")
    voice: VapiVoice
    language: Optional[SupportedLanguage] = None
    recording_format: Optional[StrictStr] = Field(default=None, alias="recordingFormat")
    __properties: ClassVar[List[str]] = ["firstMessage", "endCallMessage", "maxDurationSeconds", "voice", "language", "recordingFormat"]

    @field_validator('recording_format')
    def recording_format_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['mp3', 'wav;l16']):
            raise ValueError("must be one of enum values ('mp3', 'wav;l16')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProjectConversationConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of voice
        if self.voice:
            _dict['voice'] = self.voice.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProjectConversationConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "firstMessage": obj.get("firstMessage"),
            "endCallMessage": obj.get("endCallMessage"),
            "maxDurationSeconds": obj.get("maxDurationSeconds"),
            "voice": VapiVoice.from_dict(obj["voice"]) if obj.get("voice") is not None else None,
            "language": obj.get("language"),
            "recordingFormat": obj.get("recordingFormat")
        })
        return _obj


