# coding: utf-8

"""
    Fastify Template API

    API documentation using Swagger

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from keplar_api.models.check_permission_request import CheckPermissionRequest

class TestCheckPermissionRequest(unittest.TestCase):
    """CheckPermissionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CheckPermissionRequest:
        """Test CheckPermissionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CheckPermissionRequest`
        """
        model = CheckPermissionRequest()
        if include_optional:
            return CheckPermissionRequest(
                user_id = '',
                user_external_id = '',
                resource = 'thread',
                resource_id = '',
                action = 'read'
            )
        else:
            return CheckPermissionRequest(
                resource = 'thread',
                resource_id = '',
                action = 'read',
        )
        """

    def testCheckPermissionRequest(self):
        """Test CheckPermissionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
